@@ -21,9 +21,7 @@ where
     // pos
     write_position(writer, record.pos).await?;
 
-    let l_read_name = u8::try_from(record.read_name.len())
-        .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
-    writer.write_u8(l_read_name).await?;
+    write_l_read_name(writer, record.read_name()).await?;
 
     // mapq
     write_mapping_quality(writer, record.mapping_quality()).await?;
@@ -49,7 +47,7 @@ where
 
     writer.write_i32_le(record.template_length()).await?;
 
-    writer.write_all(&record.read_name).await?;
+    write_read_name(writer, record.read_name()).await?;
 
     write_cigar(writer, record.cigar()).await?;
 
@@ -101,6 +99,20 @@ where
     writer.write_i32_le(pos).await
 }
 
+async fn write_l_read_name<W>(writer: &mut W, read_name: &[u8]) -> io::Result<()>
+where
+    W: AsyncWrite + Unpin,
+{
+    let len = u8::try_from(read_name.len())
+        .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
+
+    let l_read_name = len
+        .checked_add(1)
+        .ok_or_else(|| io::Error::new(io::ErrorKind::InvalidInput, "invalid l_read_name"))?;
+
+    writer.write_u8(l_read_name).await
+}
+
 async fn write_mapping_quality<W>(
     writer: &mut W,
     mapping_quality: Option<sam::record::MappingQuality>,
@@ -113,6 +125,18 @@ where
     writer.write_u8(mapq).await
 }
 
+async fn write_read_name<W>(writer: &mut W, read_name: &[u8]) -> io::Result<()>
+where
+    W: AsyncWrite + Unpin,
+{
+    const NUL: u8 = 0x00;
+
+    writer.write_all(read_name).await?;
+    writer.write_all(&[NUL]).await?;
+
+    Ok(())
+}
+
 async fn write_cigar<W>(writer: &mut W, cigar: &Cigar) -> io::Result<()>
 where
     W: AsyncWrite + Unpin,
@@ -179,7 +203,7 @@ mod tests {
             .set_mate_reference_sequence_id(reference_sequence_id)
             .set_mate_position(Position::try_from(22)?)
             .set_template_length(144)
-            .set_read_name(b"r0\x00".to_vec())
+            .set_read_name(b"r0".to_vec())
             .set_cigar(Cigar::from(vec![
                 Op::new(Kind::Match, 36)?,
                 Op::new(Kind::SoftClip, 8)?,
