@@ -23,9 +23,7 @@ where
     // pos
     write_position(writer, record.pos)?;
 
-    let l_read_name = u8::try_from(record.read_name.len())
-        .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
-    writer.write_u8(l_read_name)?;
+    write_l_read_name(writer, record.read_name())?;
 
     // mapq
     write_mapping_quality(writer, record.mapping_quality())?;
@@ -51,7 +49,7 @@ where
 
     writer.write_i32::<LittleEndian>(record.template_length())?;
 
-    writer.write_all(&record.read_name)?;
+    write_read_name(writer, record.read_name())?;
 
     write_cigar(writer, record.cigar())?;
 
@@ -103,6 +101,20 @@ where
     writer.write_i32::<LittleEndian>(pos)
 }
 
+fn write_l_read_name<W>(writer: &mut W, read_name: &[u8]) -> io::Result<()>
+where
+    W: Write,
+{
+    let len = u8::try_from(read_name.len())
+        .map_err(|e| io::Error::new(io::ErrorKind::InvalidInput, e))?;
+
+    let l_read_name = len
+        .checked_add(1)
+        .ok_or_else(|| io::Error::new(io::ErrorKind::InvalidInput, "invalid l_read_name"))?;
+
+    writer.write_u8(l_read_name)
+}
+
 fn write_mapping_quality<W>(
     writer: &mut W,
     mapping_quality: Option<sam::record::MappingQuality>,
@@ -115,6 +127,18 @@ where
     writer.write_u8(mapq)
 }
 
+fn write_read_name<W>(writer: &mut W, read_name: &[u8]) -> io::Result<()>
+where
+    W: Write,
+{
+    const NUL: u8 = 0x00;
+
+    writer.write_all(read_name)?;
+    writer.write_all(&[NUL])?;
+
+    Ok(())
+}
+
 fn write_cigar<W>(writer: &mut W, cigar: &Cigar) -> io::Result<()>
 where
     W: Write,
@@ -181,7 +205,7 @@ mod tests {
             .set_mate_reference_sequence_id(reference_sequence_id)
             .set_mate_position(Position::try_from(22)?)
             .set_template_length(144)
-            .set_read_name(b"r0\x00".to_vec())
+            .set_read_name(b"r0".to_vec())
             .set_cigar(Cigar::from(vec![
                 Op::new(Kind::Match, 36)?,
                 Op::new(Kind::SoftClip, 8)?,
