@@ -647,7 +647,7 @@ mod tests {
         t(&mut buf, &Value::Int(13), &[b'i'])?;
         t(&mut buf, &Value::Float(8.0), &[b'f'])?;
         t(&mut buf, &Value::String(String::from("ndls")), &[b'Z'])?;
-        t(&mut buf, &Value::Hex(String::from("cafe")), &[b'H'])?;
+        t(&mut buf, &Value::Hex(String::from("CAFE")), &[b'H'])?;
         t(&mut buf, &Value::Int8Array(vec![1, -2]), &[b'B', b'c'])?;
         t(&mut buf, &Value::UInt8Array(vec![3, 5]), &[b'B', b'C'])?;
         t(&mut buf, &Value::Int16Array(vec![8, -13]), &[b'B', b's'])?;
@@ -683,8 +683,8 @@ mod tests {
 
         t(
             &mut buf,
-            &Value::Hex(String::from("cafe")),
-            &[b'c', b'a', b'f', b'e', 0x00],
+            &Value::Hex(String::from("CAFE")),
+            &[b'C', b'A', b'F', b'E', 0x00],
         )?;
 
         t(
